//
//  CWLineDetailCell.m
//  ResaISkane
//
//  Copyright 2010 Fredrik Olsson. All rights reserved.
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//  http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//

#import "CWLineDetailCell.h"
#import "NSDate+CWExtentions.h"
#import "UIColor+CWEditableColor.h"

@implementation CWLineDetailCell

-(void)localizeTextLabels;
{
  towardsTitleLabel.text = NSLocalizedString(@"TowardsTitle", nil);
}

+(CWLineDetailCell*)lineDetailCell;
{
  NSArray* objects = [[NSBundle mainBundle] loadNibNamed:@"CWLineDetailCell" owner:self options:nil];
  for (id object in objects) {
  	if ([object tag] == 1) {
			[object localizeTextLabels];
			return object;
    }
  }
  return nil;
}


-(CGFloat)rowHeight;
{
	if (deviationsLabel.hidden) {
  	return 64.f;
  } else {
		return 64.f + deviationsLabel.frame.size.height;
  }
}

-(void)setLine:(CWLine*)line;
{
  lineTypeImageView.image = [UIImage imageNamed:[NSString stringWithFormat:@"type-%d.png", line.type]];
  lineLabel.text = line.fullName;
  stopPointLabel.text = [NSString stringWithFormat:NSLocalizedString([line isTrain] ? @"Platform" : @"Position", nil), line.stopPoint];
	towardsLabel.text = line.towards;
	towardsTimeLabel.text = [line.actualDeparture localizedShortTimeString];
  towardsTimeLabel.textColor = [line.departure isEqualToDate:line.actualDeparture] ? [UIColor editableColor] : [UIColor warningTextColor];

  NSString* deviationsString = line.deviationsAsString;
  if (deviationsString) {
  	deviationsLabel.text = [deviationsString stringByAppendingString:@"\n"];
    deviationsLabel.hidden = NO;
  } else {
  	deviationsLabel.hidden = YES;
  }
  [self setNeedsLayout];
}


@end
